@@ -2,7 +2,7 @@
 # $Revision: #1 $ $Change: 4091 $ $DateTime: 2002/05/02 18:04:48 $
 
 package Locale::Maketext::Lexicon::Gettext;
-$Locale::Maketext::Lexicon::Gettext = '0.01';
+$Locale::Maketext::Lexicon::Gettext = '0.02';
 
 use strict;
 
@@ -22,7 +22,7 @@ Directly calling C<parse()>:
 
     use Locale::Maketext::Lexicon::Gettext;
     my %Lexicon = Locale::Maketext::Lexicon::Gettext->parse(<DATA>);
-    __DATA_
+    __DATA__
     #: Hello.pm:10
     msgid "Hello, World!"
     msgstr "Hallo, Welt!"
@@ -33,11 +33,22 @@ This module implements a perl-based C<Gettext> parser for
 B<Locale::Maketext>. It transforms all C<%1>, C<%2>... sequences
 to C<[_1]>, C<[_2]>, and so on.
 
+As an additional feature, this module also parses MIME-header style
+metadata specified in the null msgstr (C<"">), and add them to the
+C<%Lexicon> with a C<__> prefix.  For example, the example above will
+set C<__Content-Type> to C<text/plain; charset=iso8859-1>, without
+the newline or the colon.
+
+Any normal entry that duplicates a metadata entry takes precedence.
+Hence, a C<msgid "__Content-Type"> line occurs anywhere should override
+the above value.
+
 =cut
 
 sub parse {
     my $self = shift;
     my (%var, $key, @ret);
+    my @metadata;
 
     # Parse *.po; Locale::Gettext objects and *.mo are not yet supported.
     foreach (@_) {
@@ -55,15 +66,26 @@ sub parse {
 	} :
 
 	/^ *$/				? do {	# interpolate string escapes
-	    push @ret, map { transform($_) } @var{'msgid', 'msgstr'} if length $var{msgstr};
+	    push @ret, map { transform($_) } @var{'msgid', 'msgstr'}
+		if length $var{msgstr};
+	    push @metadata, parse_metadata($var{msgstr})
+		if $var{msgid} eq '';
 	    %var = ();
 	} : ();
     }
 
-    push @ret, map { transform($_) }
-	@var{'msgid', 'msgstr'} if length $var{msgstr};
+    push @ret, map { transform($_) } @var{'msgid', 'msgstr'}
+	if length $var{msgstr};
+    push @metadata, parse_metadata($var{msgstr})
+	if $var{msgid} eq '';
 
-    return @ret;
+    return (@metadata, @ret);
+}
+
+sub parse_metadata {
+    return map {
+	/^([^\x00-\x1f\x80-\xff :=]+):\s*(.*)$/ ? ("__$1", $2) : ()
+    } split(/\n+/, transform(pop));
 }
 
 sub transform {
